@@ -116,7 +116,7 @@ public class SetField
                 SetField example = new SetField();
                 pdf = PDDocument.load(new File(args[0]));
                 example.setField(pdf, args[1], args[2]);
-                pdf.save(args[0]);
+                pdf.save(calculateOutputFilename(args[0]));
             }
         }
         finally
@@ -128,6 +128,21 @@ public class SetField
         }
     }
 
+    private static String calculateOutputFilename(String filename)
+    {
+        String outputFilename;
+        if (filename.toLowerCase().endsWith(".pdf"))
+        {
+            outputFilename = filename.substring(0, filename.length() - 4);
+        }
+        else
+        {
+            outputFilename = filename;
+        }
+        outputFilename += "_filled.pdf";
+        return outputFilename;
+    }
+
     /**
      * This will print out a message telling how to use this example.
      */
