@@ -134,7 +134,9 @@ public class TSAClient
 
         if (username != null && password != null && !username.isEmpty() && !password.isEmpty())
         {
-            connection.setRequestProperty(username, password);
+            // See https://stackoverflow.com/questions/12732422/ (needs jdk8)
+            // or see implementation in 3.0
+            throw new UnsupportedOperationException("authentication not implemented yet");
         }
 
         // read response
@@ -144,6 +146,11 @@ public class TSAClient
             output = connection.getOutputStream();
             output.write(request);
         }
+        catch (IOException ex)
+        {
+            LOG.error("Exception when writing to " + this.url, ex);
+            throw ex;
+        }
         finally
         {
             IOUtils.closeQuietly(output);
@@ -158,6 +165,11 @@ public class TSAClient
             input = connection.getInputStream();
             response = IOUtils.toByteArray(input);
         }
+        catch (IOException ex)
+        {
+            LOG.error("Exception when reading from " + this.url, ex);
+            throw ex;
+        }
         finally
         {
             IOUtils.closeQuietly(input);
