@@ -79,6 +79,7 @@ import org.apache.pdfbox.util.Hex;
 
 import org.apache.wink.client.MockHttpServer;
 
+import org.bouncycastle.asn1.BEROctetString;
 import org.bouncycastle.asn1.ocsp.OCSPResponseStatus;
 import org.bouncycastle.cert.X509CertificateHolder;
 import org.bouncycastle.cert.jcajce.JcaX509CertificateConverter;
@@ -962,7 +963,8 @@ public class TestCreateSignature
             }
             Assert.assertTrue("issuer of CRL not found in Certs array", crlVerified);
 
-            byte[] crlSignatureHash = MessageDigest.getInstance("SHA-1").digest(crl.getSignature());
+            BEROctetString encodedSignature = new BEROctetString(crl.getSignature());
+            byte[] crlSignatureHash = MessageDigest.getInstance("SHA-1").digest(encodedSignature.getEncoded());
             String hexCrlSignatureHash = Hex.getString(crlSignatureHash);
             System.out.println("hexCrlSignatureHash: " + hexCrlSignatureHash);
 
@@ -993,12 +995,13 @@ public class TestCreateSignature
             BasicOCSPResp basicResponse = (BasicOCSPResp) ocspResp.getResponseObject();
             Assert.assertEquals(OCSPResponseStatus.SUCCESSFUL, ocspResp.getStatus());
             Assert.assertTrue("OCSP should have at least 1 certificate", basicResponse.getCerts().length >= 1);
-            byte[] ocspSignatureHash = MessageDigest.getInstance("SHA-1").digest(basicResponse.getSignature());
+            BEROctetString encodedSignature = new BEROctetString(basicResponse.getSignature());
+            byte[] ocspSignatureHash = MessageDigest.getInstance("SHA-1").digest(encodedSignature.getEncoded());
             String hexOcspSignatureHash = Hex.getString(ocspSignatureHash);
             System.out.println("ocspSignatureHash: " + hexOcspSignatureHash);
             long secondsOld = (System.currentTimeMillis() - basicResponse.getProducedAt().getTime()) / 1000;
             Assert.assertTrue("OCSP answer is too old, is from " + secondsOld + " seconds ago",
-                        secondsOld < 10);
+                        secondsOld < 20);
 
             X509CertificateHolder ocspCertHolder = basicResponse.getCerts()[0];
             ContentVerifierProvider verifier = new JcaContentVerifierProviderBuilder().setProvider(SecurityProvider.getProvider()).build(ocspCertHolder);
