@@ -492,7 +492,11 @@ public class CFFParser
         int charStringsOffset = charStringsEntry.getNumber(0).intValue();
         input.setPosition(charStringsOffset);
         byte[][] charStringsIndex = readIndexData(input);
-        
+        if (charStringsIndex == null)
+        {
+            throw new IOException("CharStringsIndex is missing");
+        }
+
         // charset
         DictData.Entry charsetEntry = topDict.getEntry("charset");
         CFFCharset charset;
@@ -766,24 +770,25 @@ public class CFFParser
         }
     }
 
-    private String readString(int index)
+    private String readString(int index) throws IOException
     {
-        if (index >= 0 && index <= 390)
+        if (index < 0)
+        {
+            throw new IOException("Invalid negative index when reading a string");
+        }
+        if (index <= 390)
         {
             return CFFStandardString.getName(index);
         }
-        if (index - 391 < stringIndex.length)
+        if (stringIndex != null && index - 391 < stringIndex.length)
         {
             return stringIndex[index - 391];
         }
-        else
-        {
-            // technically this maps to .notdef, but we need a unique sid name
-            return "SID" + index;
-        }
+        // technically this maps to .notdef, but we need a unique sid name
+        return "SID" + index;
     }
 
-    private String getString(DictData dict, String name)
+    private String getString(DictData dict, String name) throws IOException
     {
         DictData.Entry entry = dict.getEntry(name);
         return entry != null && entry.hasOperands() ? readString(entry.getNumber(0).intValue()) : null;
@@ -801,7 +806,7 @@ public class CFFParser
             case 1:
                 return readFormat1Encoding(dataInput, charset, format);
             default:
-                throw new IllegalArgumentException();
+                throw new IOException("Invalid encoding base format " + baseFormat);
         }
     }
 
@@ -1053,7 +1058,7 @@ public class CFFParser
             case 2:
                 return readFormat2Charset(dataInput, format, nGlyphs, isCIDFont);
             default:
-                throw new IllegalArgumentException();
+                throw new IOException("Incorrect charset format " + format);
         }
     }
 
@@ -1199,7 +1204,7 @@ public class CFFParser
         public Boolean getBoolean(String name, boolean defaultValue)
         {
             Entry entry = getEntry(name);
-            return entry != null && !entry.getArray().isEmpty() ? entry.getBoolean(0) : defaultValue;
+            return entry != null && !entry.getArray().isEmpty() ? entry.getBoolean(0, defaultValue) : defaultValue;
         }
 
         public List<Number> getArray(String name, List<Number> defaultValue)
@@ -1247,24 +1252,31 @@ public class CFFParser
                 return operands.size();
             }
 
-            public Boolean getBoolean(int index)
+            public Boolean getBoolean(int index, Boolean defaultValue)
             {
                 Number operand = operands.get(index);
                 if (operand instanceof Integer)
                 {
                     switch (operand.intValue())
                     {
-                    case 0:
-                        return Boolean.FALSE;
-                    case 1:
-                        return Boolean.TRUE;
-                    default:
-                        break;
+                        case 0:
+                            return Boolean.FALSE;
+                        case 1:
+                            return Boolean.TRUE;
+                        default:
+                            break;
                     }
                 }
-                throw new IllegalArgumentException();
+                LOG.warn("Expected boolean, got " + operand + ", returning default " + defaultValue);
+                return defaultValue;
             }
 
+            @Deprecated
+            public Boolean getBoolean(int index)
+            {
+                return getBoolean(index, Boolean.FALSE);
+            }                
+
             public boolean hasOperands()
             {
                 return !operands.isEmpty();
@@ -1282,7 +1294,7 @@ public class CFFParser
                 {
                     Number previous = result.get(i - 1);
                     Number current = result.get(i);
-                    Integer sum = previous.intValue() + current.intValue();
+                    int sum = previous.intValue() + current.intValue();
                     result.set(i, sum);
                 }
                 return result;
