@@ -69,7 +69,7 @@ public class CmapTable extends TTFTable
      * @throws IOException If there is an error reading the data.
      */
     @Override
-    public void read(TrueTypeFont ttf, TTFDataStream data) throws IOException
+    void read(TrueTypeFont ttf, TTFDataStream data) throws IOException
     {
         @SuppressWarnings({"unused", "squid:S1854", "squid:S1481"})
         int version = data.readUnsignedShort();
@@ -81,9 +81,10 @@ public class CmapTable extends TTFTable
             cmap.initData(data);
             cmaps[i] = cmap;
         }
+        int numberOfGlyphs = ttf.getNumberOfGlyphs();
         for (int i = 0; i < numberOfTables; i++)
         {
-            cmaps[i].initSubtable(this, ttf.getNumberOfGlyphs(), data);
+            cmaps[i].initSubtable(this, numberOfGlyphs, data);
         }
         initialized = true;
     }
