@@ -58,7 +58,14 @@ final class Type1Parser
     public Type1Font parse(byte[] segment1, byte[] segment2) throws IOException
     {
         font = new Type1Font(segment1, segment2);
-        parseASCII(segment1);
+        try
+        {
+            parseASCII(segment1);
+        }
+        catch (NumberFormatException ex)
+        {
+            throw new IOException(ex);
+        }
         if (segment2.length > 0)
         {
             parseBinary(segment2);
@@ -86,7 +93,7 @@ final class Type1Parser
         lexer = new Type1Lexer(bytes);
 
         // (corrupt?) synthetic font
-        if (lexer.peekToken().getText().equals("FontDirectory"))
+        if ("FontDirectory".equals(lexer.peekToken().getText()))
         {
             read(Token.NAME, "FontDirectory");
             read(Token.LITERAL); // font name
@@ -187,7 +194,7 @@ final class Type1Parser
 
     private void readEncoding() throws IOException
     {
-        if (lexer.peekToken().getKind() == Token.NAME)
+        if (lexer.peekKind(Token.NAME))
         {
             String name = lexer.nextToken().getText();
             
@@ -210,7 +217,7 @@ final class Type1Parser
             // 0 1 255 {1 index exch /.notdef put } for
             // we have to check "readonly" and "def" too
             // as some fonts don't provide any dup-values, see PDFBOX-2134
-            while (!(lexer.peekToken().getKind() == Token.NAME &&
+            while (!(lexer.peekKind(Token.NAME) &&
                     (lexer.peekToken().getText().equals("dup") ||
                     lexer.peekToken().getText().equals("readonly") ||
                     lexer.peekToken().getText().equals("def"))))
@@ -219,7 +226,7 @@ final class Type1Parser
             }
             
             Map<Integer, String> codeToName = new HashMap<Integer, String>();
-            while (lexer.peekToken().getKind() == Token.NAME &&
+            while (lexer.peekKind(Token.NAME) &&
                     lexer.peekToken().getText().equals("dup"))
             {
                 read(Token.NAME, "dup");
@@ -328,7 +335,7 @@ final class Type1Parser
             {
                 break;
             }
-            if (lexer.peekToken().getKind() == Token.NAME &&
+            if (lexer.peekKind(Token.NAME) &&
                !lexer.peekToken().getText().equals("end"))
             {
                 read(Token.NAME);
@@ -338,7 +345,7 @@ final class Type1Parser
             {
                 break;
             }
-            if (lexer.peekToken().getKind() == Token.NAME &&
+            if (lexer.peekKind(Token.NAME) &&
                 lexer.peekToken().getText().equals("end"))
             {
                 break;
@@ -391,7 +398,7 @@ final class Type1Parser
                 {
                     return value;
                 }
-                if (lexer.peekToken().getKind() == Token.START_ARRAY)
+                if (lexer.peekKind(Token.START_ARRAY))
                 {
                     openArray++;
                 }
@@ -426,8 +433,12 @@ final class Type1Parser
 
     private void readPostScriptWrapper(List<Token> value) throws IOException
     {
+        if (lexer.peekToken() == null)
+        {
+            throw new IOException("Missing start token for the system dictionary");
+        }
         // postscript wrapper (not in the Type 1 spec)
-        if (lexer.peekToken().getText().equals("systemdict"))
+        if ("systemdict".equals(lexer.peekToken().getText()))
         {
             read(Token.NAME, "systemdict");
             read(Token.LITERAL, "internaldict");
@@ -462,7 +473,12 @@ final class Type1Parser
         int openProc = 1;
         while (true)
         {
-            if (lexer.peekToken().getKind() == Token.START_PROC)
+            if (lexer.peekToken() == null)
+            {
+                throw new IOException("Malformed procedure: missing token");
+            }
+
+            if (lexer.peekKind(Token.START_PROC))
             {
                 openProc++;
             }
@@ -496,7 +512,11 @@ final class Type1Parser
         int openProc = 1;
         while (true)
         {
-            if (lexer.peekToken().getKind() == Token.START_PROC)
+            if (lexer.peekToken() == null)
+            {
+                throw new IOException("Malformed procedure: missing token");
+            }
+            if (lexer.peekKind(Token.START_PROC))
             {
                 openProc++;
             }
@@ -534,7 +554,7 @@ final class Type1Parser
 
         // find /Private dict
         Token peekToken = lexer.peekToken();
-        while (peekToken != null && !peekToken.getText().equals("Private"))
+        while (peekToken != null && !"Private".equals(peekToken.getText()))
         {
             // for a more thorough validation, the presence of "begin" before Private
             // determines how code before and following charstrings should look
@@ -561,7 +581,7 @@ final class Type1Parser
         for (int i = 0; i < length; i++)
         {
             // premature end
-            if (lexer.peekToken() == null || lexer.peekToken().getKind() != Token.LITERAL)
+            if (!lexer.peekKind(Token.LITERAL))
             {
                 break;
             }
@@ -621,8 +641,8 @@ final class Type1Parser
         // some fonts have "2 index" here, others have "end noaccess put"
         // sometimes followed by "put". Either way, we just skip until
         // the /CharStrings dict is found
-        while (!(lexer.peekToken().getKind() == Token.LITERAL &&
-                 lexer.peekToken().getText().equals("CharStrings")))
+        while (!(lexer.peekKind(Token.LITERAL)
+                && lexer.peekToken().getText().equals("CharStrings")))
         {
             lexer.nextToken();
         }
@@ -712,7 +732,7 @@ final class Type1Parser
             {
                 break;
             }
-            if (!(lexer.peekToken().getKind() == Token.NAME &&
+            if (!(lexer.peekKind(Token.NAME) &&
                   lexer.peekToken().getText().equals("dup")))
             {
                 break;
@@ -724,7 +744,11 @@ final class Type1Parser
 
             // RD
             Token charstring = read(Token.CHARSTRING);
-            font.subrs.set(index.intValue(), decrypt(charstring.getData(), CHARSTRING_KEY, lenIV));
+            int j = index.intValue();
+            if (j < font.subrs.size())
+            {
+                font.subrs.set(j, decrypt(charstring.getData(), CHARSTRING_KEY, lenIV));
+            }
             readPut();
         }
         readDef();
@@ -733,7 +757,11 @@ final class Type1Parser
     // OtherSubrs are embedded PostScript procedures which we can safely ignore
     private void readOtherSubrs() throws IOException
     {
-        if (lexer.peekToken().getKind() == Token.START_ARRAY)
+        if (lexer.peekToken() == null)
+        {
+            throw new IOException("Missing start token of OtherSubrs procedure");
+        }
+        if (lexer.peekKind(Token.START_ARRAY))
         {
             readValue();
             readDef();
@@ -774,7 +802,7 @@ final class Type1Parser
             {
                 break;
             }
-            if (lexer.peekToken().getKind() == Token.NAME &&
+            if (lexer.peekKind(Token.NAME) &&
                 lexer.peekToken().getText().equals("end"))
             {
                 break;
@@ -846,7 +874,9 @@ final class Type1Parser
     }
 
     /**
-     * Reads the next token and throws an error if it is not of the given kind.
+     * Reads the next token and throws an exception if it is not of the given kind.
+     * 
+     * @return token, never null
      */
     private Token read(Token.Kind kind) throws IOException
     {
@@ -859,13 +889,15 @@ final class Type1Parser
     }
 
     /**
-     * Reads the next token and throws an error if it is not of the given kind
+     * Reads the next token and throws an exception if it is not of the given kind
      * and does not have the given value.
+     * 
+     * @return token, never null
      */
     private void read(Token.Kind kind, String name) throws IOException
     {
         Token token = read(kind);
-        if (!token.getText().equals(name))
+        if (token.getText() == null || !token.getText().equals(name))
         {
             throw new IOException("Found " + token + " but expected " + name);
         }
@@ -874,11 +906,12 @@ final class Type1Parser
     /**
      * Reads the next token if and only if it is of the given kind and
      * has the given value.
+     * 
+     * @return token or null if not the expected one
      */
     private Token readMaybe(Token.Kind kind, String name) throws IOException
     {
-        Token token = lexer.peekToken();
-        if (token != null && token.getKind() == kind && token.getText().equals(name))
+        if (lexer.peekKind(kind) && lexer.peekToken().getText().equals(name))
         {
             return lexer.nextToken();
         }
