@@ -18,6 +18,10 @@ package org.apache.fontbox.cmap;
 
 import java.io.IOException;
 
+import org.apache.fontbox.ttf.CmapLookup;
+import org.apache.fontbox.ttf.TTFParser;
+import org.apache.fontbox.ttf.TrueTypeFont;
+
 import junit.framework.TestCase;
 
 /**
@@ -40,4 +44,18 @@ public class TestCMap extends TestCase
         cMap.addCharMapping(bs, "a");
         assertTrue("a".equals(cMap.toUnicode(200)));
     }
+
+    /**
+     * PDFBOX-3997: test unicode that is above the basic multilingual plane, here: helicopter
+     * symbol, or D83D DE81 in the Noto Emoji font.
+     *
+     * @throws IOException
+     */
+    public void testPDFBox3997() throws IOException
+    {
+        TrueTypeFont ttf = new TTFParser().parse("target/pdfs/NotoEmoji-Regular.ttf");
+        CmapLookup cmap = ttf.getUnicodeCmapLookup(false);
+        assertEquals(886, cmap.getGlyphId(0x1F681));
+        ttf.close();
+    }
 }
