@@ -64,19 +64,18 @@ public class DrawObject extends OperatorProcessor
             try
             {
                 context.increaseLevel();
-                if (context.getLevel() > 25)
+                if (context.getLevel() > 50)
                 {
                     LOG.error("recursion is too deep, skipping form XObject");
                     return;
                 }
-                PDFormXObject form = (PDFormXObject) xobject;
-                if (form instanceof PDTransparencyGroup)
+                if (xobject instanceof PDTransparencyGroup)
                 {
-                    context.showTransparencyGroup((PDTransparencyGroup) form);
+                    context.showTransparencyGroup((PDTransparencyGroup) xobject);
                 }
                 else
                 {
-                    context.showForm(form);
+                    context.showForm((PDFormXObject) xobject);
                 }
             }
             finally
