@@ -551,11 +551,10 @@ public class COSArray extends COSBase implements Iterable<COSBase>, COSUpdateInf
     public float[] toFloatArray()
     {
         float[] retval = new float[size()];
-        for (int i = 0; i < size(); i++)
+        for (int i = 0; i < retval.length; i++)
         {
             COSBase base = getObject(i);
-            retval[i] =
-                base instanceof COSNumber ? ((COSNumber) base).floatValue() : 0;
+            retval[i] = base instanceof COSNumber ? ((COSNumber) base).floatValue() : 0;
         }
         return retval;
     }
