@@ -58,6 +58,7 @@ public final class COSName extends COSBase implements Comparable<COSName>
     public static final COSName AESV2 = new COSName("AESV2");
     public static final COSName AESV3 = new COSName("AESV3");
     public static final COSName AFTER = new COSName("After");
+    public static final COSName AI_META_DATA = new COSName("AIMetaData");
     public static final COSName AIS = new COSName("AIS");
     public static final COSName ALL_OFF = new COSName("AllOff");
     public static final COSName ALL_ON = new COSName("AllOn");
@@ -130,6 +131,7 @@ public final class COSName extends COSBase implements Comparable<COSName>
     public static final COSName CH = new COSName("Ch");
     public static final COSName CHAR_PROCS = new COSName("CharProcs");
     public static final COSName CHAR_SET = new COSName("CharSet");
+    public static final COSName CI = new COSName("CI");
     public static final COSName CICI_SIGNIT = new COSName("CICI.SignIt");
     public static final COSName CID_FONT_TYPE0 = new COSName("CIDFontType0");
     public static final COSName CID_FONT_TYPE2 = new COSName("CIDFontType2");
@@ -145,6 +147,11 @@ public final class COSName extends COSBase implements Comparable<COSName>
     public static final COSName CO = new COSName("CO");
     public static final COSName COLOR = new COSName("Color");
     public static final COSName COLLECTION = new COSName("Collection");
+    public static final COSName COLLECTION_ITEM = new COSName("CollectionItem");
+    public static final COSName COLLECTION_FIELD = new COSName("CollectionField");
+    public static final COSName COLLECTION_SCHEMA = new COSName("CollectionSchema");
+    public static final COSName COLLECTION_SORT = new COSName("CollectionSort");
+    public static final COSName COLLECTION_SUBITEM = new COSName("CollectionSubitem");
     public static final COSName COLOR_BURN = new COSName("ColorBurn");
     public static final COSName COLOR_DODGE = new COSName("ColorDodge");
     public static final COSName COLORANTS = new COSName("Colorants");
@@ -297,6 +304,7 @@ public final class COSName extends COSBase implements Comparable<COSName>
     public static final COSName IDENTITY_H = new COSName("Identity-H");
     public static final COSName IDENTITY_V = new COSName("Identity-V");
     public static final COSName IF = new COSName("IF");
+    public static final COSName ILLUSTRATOR = new COSName("Illustrator");
     public static final COSName IM = new COSName("IM");
     public static final COSName IMAGE = new COSName("Image");
     public static final COSName IMAGE_MASK = new COSName("ImageMask");
@@ -435,12 +443,14 @@ public final class COSName extends COSBase implements Comparable<COSName>
     public static final COSName PARENT = new COSName("Parent");
     public static final COSName PARENT_TREE = new COSName("ParentTree");
     public static final COSName PARENT_TREE_NEXT_KEY = new COSName("ParentTreeNextKey");
+    public static final COSName PART = new COSName("Part");
     public static final COSName PATH = new COSName("Path");
     public static final COSName PATTERN = new COSName("Pattern");
     public static final COSName PATTERN_TYPE = new COSName("PatternType");
     public static final COSName PDF_DOC_ENCODING = new COSName("PDFDocEncoding");
     public static final COSName PERMS = new COSName("Perms");
     public static final COSName PERCEPTUAL = new COSName("Perceptual");
+    public static final COSName PIECE_INFO = new COSName("PieceInfo");
     public static final COSName PG = new COSName("Pg");
     public static final COSName PRE_RELEASE = new COSName("PreRelease");
     public static final COSName PREDICTOR = new COSName("Predictor");
@@ -448,6 +458,7 @@ public final class COSName extends COSBase implements Comparable<COSName>
     public static final COSName PRINT_AREA = new COSName("PrintArea");
     public static final COSName PRINT_CLIP = new COSName("PrintClip");
     public static final COSName PRINT_SCALING = new COSName("PrintScaling");
+    public static final COSName PRIVATE = new COSName("Private");
     public static final COSName PROC_SET = new COSName("ProcSet");
     public static final COSName PROCESS = new COSName("Process");
     public static final COSName PRODUCER = new COSName("Producer");
@@ -469,6 +480,7 @@ public final class COSName extends COSBase implements Comparable<COSName>
     public static final COSName REPEAT = new COSName("Repeat");
     public static final COSName RECIPIENTS = new COSName("Recipients");
     public static final COSName RECT = new COSName("Rect");
+    public static final COSName REFERENCE = new COSName("Reference");
     public static final COSName REGISTRY = new COSName("Registry");
     public static final COSName REGISTRY_NAME = new COSName("RegistryName");
     public static final COSName RENAME = new COSName("Rename");
@@ -496,6 +508,7 @@ public final class COSName extends COSBase implements Comparable<COSName>
     public static final COSName SHADING_TYPE = new COSName("ShadingType");
     public static final COSName SIG = new COSName("Sig");
     public static final COSName SIG_FLAGS = new COSName("SigFlags");
+    public static final COSName SIG_REF = new COSName("SigRef");
     public static final COSName SIZE = new COSName("Size");
     public static final COSName SM = new COSName("SM");
     public static final COSName SMASK = new COSName("SMask");
@@ -547,6 +560,8 @@ public final class COSName extends COSBase implements Comparable<COSName>
     public static final COSName TR2 = new COSName("TR2");
     public static final COSName TRAPPED = new COSName("Trapped");
     public static final COSName TRANS = new COSName("Trans");
+    public static final COSName TRANSFORM_METHOD = new COSName("TransformMethod");
+    public static final COSName TRANSFORM_PARAMS = new COSName("TransformParams");
     public static final COSName TRANSPARENCY = new COSName("Transparency");
     public static final COSName TREF = new COSName("TRef");
     public static final COSName TRIM_BOX = new COSName("TrimBox");
