@@ -110,6 +110,10 @@ public final class COSOutputStream extends FilterOutputStream
     @Override
     public void flush() throws IOException
     {
+        if (buffer == null)
+        {
+            super.flush();
+        }
     }
 
     @Override
