@@ -108,7 +108,7 @@ public class ScratchFile implements Closeable
     public ScratchFile(MemoryUsageSetting memUsageSetting) throws IOException
     {
         maxMainMemoryIsRestricted = (!memUsageSetting.useMainMemory()) || memUsageSetting.isMainMemoryRestricted();
-        useScratchFile = maxMainMemoryIsRestricted ? memUsageSetting.useTempFile() : false;
+        useScratchFile = maxMainMemoryIsRestricted && memUsageSetting.useTempFile();
         scratchFileDirectory = useScratchFile ? memUsageSetting.getTempDir() : null;
 
         if ((scratchFileDirectory != null) && (!scratchFileDirectory.isDirectory()))
@@ -193,7 +193,7 @@ public class ScratchFile implements Closeable
      * if no new pages could be added because we reached the maximum of
      * {@link Integer#MAX_VALUE} pages.
      * 
-     * <p>If scratch file uage is allowed and scratch file does not exist already
+     * <p>If scratch file usage is allowed and scratch file does not exist already
      * it will be created.</p>
      * 
      * <p>Only to be called under synchronization on {@link #freePages}.</p>
@@ -234,16 +234,37 @@ public class ScratchFile implements Closeable
                 
                 if (expectedFileLen != fileLen)
                 {
-                    throw new IOException("Expected scratch file size of " + expectedFileLen + " but found " + fileLen);
+                    throw new IOException("Expected scratch file size of " + expectedFileLen +
+                                          " but found " + fileLen + " in file " + file);
                 }
                     
-                // enlarge if we do not overflow
+                // enlarge if we do not int overflow
                 if (pageCount + ENLARGE_PAGE_COUNT > pageCount)
                 {
+                    if (LOG.isDebugEnabled())
+                    {
+                        LOG.debug("file: " + file);
+                        LOG.debug("fileLen before: " + fileLen + ", raf length: " + raf.length() + 
+                                  ", file length: " + file.length());
+                    }
                     fileLen += ENLARGE_PAGE_COUNT * PAGE_SIZE;
-        
+
                     raf.setLength(fileLen);
-        
+                    if (LOG.isDebugEnabled())
+                    {
+                        LOG.debug("fileLen after1: " + fileLen + ", raf length: " + raf.length() + 
+                                  ", file length: " + file.length());
+                    }
+                    if (fileLen != raf.length())
+                    {
+                        // PDFBOX-4601 possible AWS lambda bug that setLength() doesn't throw
+                        // if not enough space
+                        long origFilePointer = raf.getFilePointer();
+                        raf.seek(fileLen - 1);
+                        raf.write(0);
+                        raf.seek(origFilePointer);
+                        LOG.debug("fileLen after2:  " + fileLen + ", raf length: " + raf.length() + ", file length: " + file.length());
+                    }
                     freePages.set(pageCount, pageCount + ENLARGE_PAGE_COUNT);
                 }
             }
@@ -418,7 +439,7 @@ public class ScratchFile implements Closeable
         ScratchFileBuffer buf = new ScratchFileBuffer(this);
         
         byte[] byteBuffer = new byte[8192];
-        int bytesRead = 0;
+        int bytesRead;
         while ((bytesRead = input.read(byteBuffer)) > -1)
         {
             buf.write(byteBuffer, 0, bytesRead);
@@ -488,15 +509,9 @@ public class ScratchFile implements Closeable
                 }
             }
             
-            if (file != null)
+            if (file != null && !file.delete() && file.exists() && ioexc == null)
             {
-                if (!file.delete())
-                {
-                    if (file.exists() && (ioexc == null))
-                    {
-                        ioexc = new IOException("Error deleting scratch file: " + file.getAbsolutePath());
-                    }
-                }
+                ioexc = new IOException("Error deleting scratch file: " + file.getAbsolutePath());
             }
         }
         
