@@ -287,11 +287,10 @@ public class LayerUtility
         for (Map.Entry<COSName, COSBase> entry : orgDict.entrySet())
         {
             COSName key = entry.getKey();
-            if (!filter.contains(key.getName()))
+            if (filter.contains(key.getName()))
             {
-                continue;
+                targetDict.setItem(key, cloner.cloneForNewDocument(entry.getValue()));
             }
-            targetDict.setItem(key, cloner.cloneForNewDocument(entry.getValue()));
         }
     }
 
