@@ -24,6 +24,7 @@ import java.io.InputStream;
 import java.io.OutputStream;
 import java.math.BigDecimal;
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
@@ -97,8 +98,9 @@ public class Overlay implements Closeable
     /**
      * This will add overlays to a document.
      *
-     * @param specificPageOverlayFile Optional map of overlay files for specific pages. The page
-     * numbers are 1-based. The map must be empty (but not null) if no specific mappings are used.
+     * @param specificPageOverlayFile Optional map of overlay files of which the first page will be
+     * used for specific pages of the input document. The page numbers are 1-based. The map must be
+     * empty (but not null) if no specific mappings are used.
      *
      * @return The modified input PDF document, which has to be saved and closed by the caller. If
      * the input document was passed by {@link #setInputPDF(PDDocument) setInputPDF(PDDocument)}
@@ -108,20 +110,20 @@ public class Overlay implements Closeable
      */
     public PDDocument overlay(Map<Integer, String> specificPageOverlayFile) throws IOException
     {
-        Map<String, PDDocument> loadedDocuments = new HashMap<String, PDDocument>();
-        Map<PDDocument, LayoutPage> layouts = new HashMap<PDDocument, LayoutPage>();
+        Map<String, LayoutPage> layouts = new HashMap<String, LayoutPage>();
+        String path;
         loadPDFs();
         for (Map.Entry<Integer, String> e : specificPageOverlayFile.entrySet())
         {
-            PDDocument doc = loadedDocuments.get(e.getValue());
-            if (doc == null)
+            path = e.getValue();
+            LayoutPage layoutPage = layouts.get(path);
+            if (layoutPage == null)
             {
-                doc = loadPDF(e.getValue());
-                loadedDocuments.put(e.getValue(), doc);
-                layouts.put(doc, getLayoutPage(doc));
+                PDDocument doc = loadPDF(path);
+                layouts.put(path, getLayoutPage(doc));
                 openDocuments.add(doc);
             }
-            specificPageOverlayPage.put(e.getKey(), layouts.get(doc));
+            specificPageOverlayPage.put(e.getKey(), layoutPage);
         }
         processPages(inputPDFDocument);
         return inputPDFDocument;
@@ -285,11 +287,24 @@ public class Overlay implements Closeable
         }
     }
 
+    /**
+     * Create a LayoutPage object from the first page of the given document.
+     *
+     * @param doc
+     * @return
+     * @throws IOException 
+     */
     private LayoutPage getLayoutPage(PDDocument doc) throws IOException
     {
         return createLayoutPage(doc.getPage(0));
     }
 
+    /**
+     * Create a LayoutPage object from given PDPage object.
+     *
+     * @return
+     * @throws IOException 
+     */
     private LayoutPage createLayoutPage(PDPage page) throws IOException
     {
         COSBase contents = page.getCOSObject().getDictionaryObject(COSName.CONTENTS);
@@ -334,16 +349,17 @@ public class Overlay implements Closeable
     // get the content streams as a list
     private List<COSStream> createContentStreamList(COSBase contents) throws IOException
     {
-        List<COSStream> contentStreams = new ArrayList<COSStream>();
         if (contents == null)
         {
-            return contentStreams;
+            return Collections.emptyList();
         }
-        else if (contents instanceof COSStream)
+        if (contents instanceof COSStream)
         {
-            contentStreams.add((COSStream) contents);
+            return Collections.singletonList((COSStream) contents);
         }
-        else if (contents instanceof COSArray)
+
+        List<COSStream> contentStreams = new ArrayList<COSStream>();
+        if (contents instanceof COSArray)
         {
             for (COSBase item : (COSArray) contents)
             {
