@@ -170,13 +170,23 @@ public abstract class BaseParser
         }
         if (!(generationNumber instanceof COSInteger))
         {
-            LOG.error("expected number, actual=" + value + " at offset " + genOffset);
+            LOG.error("expected number, actual=" + generationNumber + " at offset " + genOffset);
+            return COSNull.NULL;
+        }
+        long objNumber = ((COSInteger) value).longValue();
+        if (objNumber <= 0)
+        {
+            LOG.warn("invalid object number value =" + objNumber + " at offset " + numOffset);
+            return COSNull.NULL;
+        }
+        int genNumber = ((COSInteger) generationNumber).intValue();
+        if (genNumber < 0)
+        {
+            LOG.error("invalid generation number value =" + genNumber + " at offset " + numOffset);
             return COSNull.NULL;
         }
-        COSObjectKey key = new COSObjectKey(((COSInteger) value).longValue(),
-                ((COSInteger) generationNumber).intValue());
         // dereference the object
-        return getObjectFromPool(key);
+        return getObjectFromPool(new COSObjectKey(objNumber, genNumber));
     }
 
     private COSBase getObjectFromPool(COSObjectKey key) throws IOException
@@ -285,6 +295,10 @@ public abstract class BaseParser
     private boolean parseCOSDictionaryNameValuePair(COSDictionary obj) throws IOException
     {
         COSName key = parseCOSName();
+        if (key == null || key.getName().isEmpty())
+        {
+            LOG.warn("Empty COSName at offset " + seqSource.getPosition());
+        }
         COSBase value = parseCOSDictionaryValue();
         skipSpaces();
         if (value == null)
@@ -764,12 +778,12 @@ public abstract class BaseParser
         String string;
         if (isValidUTF8(bytes))
         {
-            string = new String(buffer.toByteArray(), Charsets.UTF_8);
+            string = new String(bytes, Charsets.UTF_8);
         }
         else
         {
             // some malformed PDFs don't use UTF-8 see PDFBOX-3347
-            string = new String(buffer.toByteArray(), Charsets.WINDOWS_1252);
+            string = new String(bytes, Charsets.WINDOWS_1252);
         }
         return COSName.getPDFName(string);
     }
@@ -1090,7 +1104,8 @@ public abstract class BaseParser
     {
         if (seqSource.isEOF())
         {
-            throw new IOException( "Error: End-of-File, expected line");
+            throw new IOException( "Error: End-of-File, expected line at offset " +
+                    seqSource.getPosition());
         }
 
         StringBuilder buffer = new StringBuilder( 11 );
