@@ -31,7 +31,6 @@ import org.apache.pdfbox.cos.COSDictionary;
 import org.apache.pdfbox.cos.COSName;
 import org.apache.pdfbox.cos.COSNull;
 import org.apache.pdfbox.cos.COSNumber;
-import org.apache.pdfbox.cos.COSObject;
 import org.apache.pdfbox.cos.COSStream;
 import org.apache.pdfbox.io.RandomAccessBuffer;
 import org.apache.pdfbox.pdmodel.common.PDStream;
@@ -96,9 +95,8 @@ public class PDFStreamParser extends BaseParser
      * Constructor.
      *
      * @param bytes the bytes to parse.
-     * @throws IOException If there is an error initializing the stream.
      */
-    public PDFStreamParser(byte[] bytes) throws IOException
+    public PDFStreamParser(byte[] bytes)
     {
         super(new RandomAccessSource(new RandomAccessBuffer(bytes)));
     }
@@ -198,16 +196,6 @@ public class PDFStreamParser extends BaseParser
                 {
                     return Operator.getOperator(next);
                 }
-            case 'R':
-                String line = readString();
-                if( line.equals( "R" ) )
-                {
-                    return new COSObject(null);
-                }
-                else
-                {
-                    return Operator.getOperator(line);
-                }
             case '0':
             case '1':
             case '2':
@@ -260,6 +248,12 @@ public class PDFStreamParser extends BaseParser
                     while ((nextToken = parseNextToken()) instanceof COSName)
                     {
                         Object value = parseNextToken();
+                        if (!(value instanceof COSBase))
+                        {
+                            LOG.warn("Unexpected token in inline image dictionary at offset " +
+                                    seqSource.getPosition());
+                            break;
+                        }
                         imageParams.setItem((COSName) nextToken, (COSBase) value);
                     }
                     // final token will be the image data, maybe??
@@ -320,8 +314,8 @@ public class PDFStreamParser extends BaseParser
                 return COSNull.NULL;
             default:
                 // we must be an operator
-                String operator = readOperator();
-                if (operator.trim().length() > 0)
+                String operator = readOperator().trim();
+                if (operator.length() > 0)
                 {
                     return Operator.getOperator(operator);
                 }
