@@ -29,6 +29,7 @@ import org.apache.pdfbox.cos.COSDictionary;
 import org.apache.pdfbox.cos.COSFloat;
 import org.apache.pdfbox.cos.COSInteger;
 import org.apache.pdfbox.cos.COSName;
+import org.apache.pdfbox.cos.COSNull;
 import org.apache.pdfbox.cos.COSString;
 import org.apache.pdfbox.util.Charsets;
 
@@ -144,11 +145,10 @@ public class ContentStreamWriter
             output.write(COSWriter.ARRAY_OPEN);
             for( int i=0; i<array.size(); i++ )
             {
-                writeObject( array.get( i ) );
-                output.write( SPACE );
+                writeObject(array.get(i));
             }
-
-            output.write( COSWriter.ARRAY_CLOSE );
+            output.write(COSWriter.ARRAY_CLOSE);
+            output.write(SPACE);
         }
         else if( o instanceof COSDictionary )
         {
@@ -158,10 +158,8 @@ public class ContentStreamWriter
             {
                 if (entry.getValue() != null)
                 {
-                    writeObject( entry.getKey() );
-                    output.write( SPACE );
-                    writeObject( entry.getValue() );
-                    output.write( SPACE );
+                    writeObject(entry.getKey());
+                    writeObject(entry.getValue());
                 }
             }
             output.write( COSWriter.DICT_CLOSE );
@@ -173,6 +171,7 @@ public class ContentStreamWriter
             if (op.getName().equals(OperatorName.BEGIN_INLINE_IMAGE))
             {
                 output.write(OperatorName.BEGIN_INLINE_IMAGE.getBytes(Charsets.ISO_8859_1));
+                output.write(EOL);
                 COSDictionary dic = op.getImageParameters();
                 for( COSName key : dic.keySet() )
                 {
@@ -195,6 +194,11 @@ public class ContentStreamWriter
                 output.write( EOL );
             }
         }
+        else if (o instanceof COSNull)
+        {
+            output.write("null".getBytes(Charsets.ISO_8859_1));
+            output.write(SPACE);
+        }
         else
         {
             throw new IOException( "Error:Unknown type in content stream:" + o );
