@@ -367,14 +367,15 @@ public class PDDocument implements Closeable
         // Create SignatureForm for signature and append it to the document
 
         // Get the first valid page
-        int pageCount = getNumberOfPages();
+        PDPageTree pageTree = getPages();
+        int pageCount = pageTree.getCount();
         if (pageCount == 0)
         {
             throw new IllegalStateException("Cannot sign an empty document");
         }
 
         int startIndex = Math.min(Math.max(options.getPage(), 0), pageCount - 1);
-        PDPage page = getPage(startIndex);
+        PDPage page = pageTree.get(startIndex);
 
         // Get the AcroForm from the Root-Dictionary and append the annotation
         PDDocumentCatalog catalog = getDocumentCatalog();
@@ -403,16 +404,19 @@ public class PDDocument implements Closeable
         {
             acroForm.getCOSObject().setItem(COSName.FIELDS, new COSArray());
         }
+        PDAnnotationWidget firstWidget;
         if (signatureField == null)
         {
             signatureField = new PDSignatureField(acroForm);
             // append the signature object
             signatureField.setValue(sigObject);
+            firstWidget = signatureField.getWidgets().get(0);
             // backward linking
-            signatureField.getWidgets().get(0).setPage(page);
+            firstWidget.setPage(page);
         }
         else
         {
+            firstWidget = signatureField.getWidgets().get(0);
             sigObject.getCOSObject().setNeedToBeUpdated(true);
         }
 
@@ -422,7 +426,7 @@ public class PDDocument implements Closeable
         // to conform PDF/A-1 requirement:
         // The /F key's Print flag bit shall be set to 1 and 
         // its Hidden, Invisible and NoView flag bits shall be set to 0
-        signatureField.getWidgets().get(0).setPrinted(true);
+        firstWidget.setPrinted(true);
         // This may be troublesome if several form fields are signed,
         // see thread from PDFBox users mailing list 17.2.2021 - 19.2.2021
         // https://mail-archives.apache.org/mod_mbox/pdfbox-users/202102.mbox/thread
@@ -450,11 +454,11 @@ public class PDDocument implements Closeable
         // Distinction of case for visual and non-visual signature
         if (visualSignature == null)
         {
-            prepareNonVisibleSignature(signatureField);
+            prepareNonVisibleSignature(firstWidget);
             return;
         }
 
-        prepareVisibleSignature(signatureField, acroForm, visualSignature);
+        prepareVisibleSignature(firstWidget, acroForm, visualSignature);
 
         // Create Annotation / Field for signature
         List<PDAnnotation> annotations = page.getAnnotations();
@@ -466,20 +470,20 @@ public class PDDocument implements Closeable
 
         // Get the annotations of the page and append the signature-annotation to it
         // take care that page and acroforms do not share the same array (if so, we don't need to add it twice)
-        if (!(annotations instanceof COSArrayList &&
+        if (!(checkFields &&
+              annotations instanceof COSArrayList &&
               acroFormFields instanceof COSArrayList &&
-              ((COSArrayList<?>) annotations).toList().equals(((COSArrayList<?>) acroFormFields).toList()) &&
-              checkFields))
+              ((COSArrayList) annotations).toList().
+                      equals(((COSArrayList) acroFormFields).toList())))
         {
-            PDAnnotationWidget widget = signatureField.getWidgets().get(0);
             // use check to prevent the annotation widget from appearing twice
-            if (checkSignatureAnnotation(annotations, widget))
+            if (checkSignatureAnnotation(annotations, firstWidget))
             {
-                widget.getCOSObject().setNeedToBeUpdated(true);
+                firstWidget.getCOSObject().setNeedToBeUpdated(true);
             }
             else
             {
-                annotations.add(widget);
+                annotations.add(firstWidget);
             }   
         }
         page.getCOSObject().setNeedToBeUpdated(true);
@@ -551,7 +555,7 @@ public class PDDocument implements Closeable
         return false;
     }
 
-    private void prepareVisibleSignature(PDSignatureField signatureField, PDAcroForm acroForm, 
+    private void prepareVisibleSignature(PDAnnotationWidget firstWidget, PDAcroForm acroForm, 
             COSDocument visualSignature)
     {
         // Obtain visual signature object
@@ -573,7 +577,7 @@ public class PDDocument implements Closeable
                 COSBase type = cosBaseDict.getDictionaryObject(COSName.TYPE);
                 if (annotNotFound && COSName.ANNOT.equals(type))
                 {
-                    assignSignatureRectangle(signatureField, cosBaseDict);
+                    assignSignatureRectangle(firstWidget, cosBaseDict);
                     annotNotFound = false;
                 }
 
@@ -582,7 +586,7 @@ public class PDDocument implements Closeable
                 COSBase apDict = cosBaseDict.getDictionaryObject(COSName.AP);
                 if (sigFieldNotFound && COSName.SIG.equals(fieldType) && apDict instanceof COSDictionary)
                 {
-                    assignAppearanceDictionary(signatureField, (COSDictionary) apDict);
+                    assignAppearanceDictionary(firstWidget, (COSDictionary) apDict);
                     assignAcroFormDefaultResource(acroForm, cosBaseDict);
                     sigFieldNotFound = false;
                 }
@@ -595,26 +599,26 @@ public class PDDocument implements Closeable
         }
     }
 
-    private void assignSignatureRectangle(PDSignatureField signatureField, COSDictionary annotDict)
+    private void assignSignatureRectangle(PDAnnotationWidget firstWidget, COSDictionary annotDict)
     {
         // Read and set the rectangle for visual signature
-        COSArray rectArray = (COSArray) annotDict.getDictionaryObject(COSName.RECT);
-        PDRectangle existingRectangle = signatureField.getWidgets().get(0).getRectangle();
+        PDRectangle existingRectangle = firstWidget.getRectangle();
 
         //in case of an existing field keep the original rect
         if (existingRectangle == null || existingRectangle.getCOSArray().size() != 4)
         {
+            COSArray rectArray = (COSArray) annotDict.getDictionaryObject(COSName.RECT);
             PDRectangle rect = new PDRectangle(rectArray);
-            signatureField.getWidgets().get(0).setRectangle(rect);
+            firstWidget.setRectangle(rect);
         }
     }
 
-    private void assignAppearanceDictionary(PDSignatureField signatureField, COSDictionary apDict)
+    private void assignAppearanceDictionary(PDAnnotationWidget firstWidget, COSDictionary apDict)
     {
         // read and set Appearance Dictionary
         PDAppearanceDictionary ap = new PDAppearanceDictionary(apDict);
         apDict.setDirect(true);
-        signatureField.getWidgets().get(0).setAppearance(ap);
+        firstWidget.setAppearance(ap);
     }
 
     private void assignAcroFormDefaultResource(PDAcroForm acroForm, COSDictionary newDict)
@@ -646,19 +650,19 @@ public class PDDocument implements Closeable
         }
     }
 
-    private void prepareNonVisibleSignature(PDSignatureField signatureField)
+    private void prepareNonVisibleSignature(PDAnnotationWidget firstWidget)
     {
         // "Signature fields that are not intended to be visible shall
         // have an annotation rectangle that has zero height and width."
         // Set rectangle for non-visual signature to rectangle array [ 0 0 0 0 ]
-        signatureField.getWidgets().get(0).setRectangle(new PDRectangle());
+        firstWidget.setRectangle(new PDRectangle());
         
         // The visual appearance must also exist for an invisible signature but may be empty.
         PDAppearanceDictionary appearanceDictionary = new PDAppearanceDictionary();
         PDAppearanceStream appearanceStream = new PDAppearanceStream(this);
         appearanceStream.setBBox(new PDRectangle());
         appearanceDictionary.setNormalAppearance(appearanceStream);
-        signatureField.getWidgets().get(0).setAppearance(appearanceDictionary);
+        firstWidget.setAppearance(appearanceDictionary);
     }
 
     /**
