@@ -161,7 +161,14 @@ public abstract class PDFunction implements COSObjectable
         if (numberOfOutputValues == -1)
         {
             COSArray rangeValues = getRangeValues();
-            numberOfOutputValues = rangeValues.size() / 2;
+            if (rangeValues == null)
+            {
+                numberOfOutputValues = 0;
+            }
+            else
+            {
+                numberOfOutputValues = rangeValues.size() / 2;
+            }
         }
         return numberOfOutputValues;
     }
