@@ -27,6 +27,7 @@ import java.security.InvalidKeyException;
 import java.security.KeyStoreException;
 import java.security.NoSuchAlgorithmException;
 import java.security.PrivateKey;
+import java.security.Provider;
 import java.security.SecureRandom;
 import java.security.cert.CertificateEncodingException;
 import java.security.cert.X509Certificate;
@@ -44,12 +45,12 @@ import org.apache.pdfbox.cos.COSArray;
 import org.apache.pdfbox.cos.COSName;
 import org.apache.pdfbox.cos.COSString;
 import org.apache.pdfbox.pdmodel.PDDocument;
+import org.bouncycastle.asn1.ASN1Encoding;
 import org.bouncycastle.asn1.ASN1InputStream;
 import org.bouncycastle.asn1.ASN1ObjectIdentifier;
 import org.bouncycastle.asn1.ASN1Primitive;
 import org.bouncycastle.asn1.ASN1Set;
 import org.bouncycastle.asn1.DEROctetString;
-import org.bouncycastle.asn1.DEROutputStream;
 import org.bouncycastle.asn1.DERSet;
 import org.bouncycastle.asn1.cms.ContentInfo;
 import org.bouncycastle.asn1.cms.EncryptedContentInfo;
@@ -68,6 +69,7 @@ import org.bouncycastle.cms.KeyTransRecipientId;
 import org.bouncycastle.cms.RecipientId;
 import org.bouncycastle.cms.RecipientInformation;
 import org.bouncycastle.cms.jcajce.JceKeyTransEnvelopedRecipient;
+import org.bouncycastle.util.Arrays;
 
 /**
  * This class implements the public key security handler described in the PDF specification.
@@ -83,8 +85,6 @@ public final class PublicKeySecurityHandler extends SecurityHandler
     private static final String SUBFILTER4 = "adbe.pkcs7.s4";
     private static final String SUBFILTER5 = "adbe.pkcs7.s5";
 
-    private PublicKeyProtectionPolicy policy = null;
-    
     /**
      * Constructor.
      */
@@ -95,12 +95,12 @@ public final class PublicKeySecurityHandler extends SecurityHandler
     /**
      * Constructor used for encryption.
      *
-     * @param p The protection policy.
+     * @param publicKeyProtectionPolicy The protection policy.
      */
-    public PublicKeySecurityHandler(PublicKeyProtectionPolicy p)
+    public PublicKeySecurityHandler(PublicKeyProtectionPolicy publicKeyProtectionPolicy)
     {
-        policy = p;
-        this.keyLength = policy.getEncryptionKeyLength();
+        setProtectionPolicy(publicKeyProtectionPolicy);
+        setKeyLength(publicKeyProtectionPolicy.getEncryptionKeyLength());
     }
 
     /**
@@ -125,13 +125,20 @@ public final class PublicKeySecurityHandler extends SecurityHandler
         if (!(decryptionMaterial instanceof PublicKeyDecryptionMaterial))
         {
             throw new IOException(
-                    "Provided decryption material is not compatible with the document");
+                    "Provided decryption material is not compatible with the document - "
+                            + "did you pass a null keyStore?");
         }
 
-        setDecryptMetadata(encryption.isEncryptMetaData());
-        if (encryption.getLength() != 0)
+        PDCryptFilterDictionary defaultCryptFilterDictionary = encryption.getDefaultCryptFilterDictionary();
+        if (defaultCryptFilterDictionary != null && defaultCryptFilterDictionary.getLength() != 0)
         {
-            this.keyLength = encryption.getLength();
+            setKeyLength(defaultCryptFilterDictionary.getLength());
+            setDecryptMetadata(defaultCryptFilterDictionary.isEncryptMetaData());
+        }
+        else if (encryption.getLength() != 0)
+        {
+            setKeyLength(encryption.getLength());
+            setDecryptMetadata(encryption.isEncryptMetaData());
         }
 
         PublicKeyDecryptionMaterial material = (PublicKeyDecryptionMaterial) decryptionMaterial;
@@ -152,11 +159,14 @@ public final class PublicKeySecurityHandler extends SecurityHandler
             byte[] envelopedData = null;
 
             // the bytes of each recipient in the recipients array
-            COSArray array = (COSArray) encryption.getCOSObject().getItem(COSName.RECIPIENTS);
+            COSArray array = encryption.getCOSObject().getCOSArray(COSName.RECIPIENTS);
+            if (array == null && defaultCryptFilterDictionary != null)
+            {
+                array = defaultCryptFilterDictionary.getCOSObject().getCOSArray(COSName.RECIPIENTS);
+            }
             if (array == null)
             {
-                PDCryptFilterDictionary defaultCryptFilterDictionary = encryption.getDefaultCryptFilterDictionary();
-                array = (COSArray) defaultCryptFilterDictionary.getCOSObject().getItem(COSName.RECIPIENTS);
+                throw new IOException("/Recipients entry is missing in encryption dictionary");
             }
             byte[][] recipientFieldsBytes = new byte[array.size()][];
             //TODO encryption.getRecipientsLength() and getRecipientStringAt() should be deprecated
@@ -238,12 +248,25 @@ public final class PublicKeySecurityHandler extends SecurityHandler
             byte[] mdResult;
             if (encryption.getVersion() == 4 || encryption.getVersion() == 5)
             {
-                mdResult = MessageDigests.getSHA256().digest(sha1Input);
+                if (!isDecryptMetadata())
+                {
+                    // "4 bytes with the value 0xFF if the key being generated is intended for use in
+                    // document-level encryption and the document metadata is being left as plaintext"
+                    sha1Input = Arrays.copyOf(sha1Input, sha1Input.length + 4);
+                    System.arraycopy(new byte[]{ (byte) 0xff, (byte) 0xff, (byte) 0xff, (byte) 0xff}, 0, sha1Input, sha1Input.length - 4, 4);
+                }
+                if (encryption.getVersion() == 4)
+                {
+                    mdResult = MessageDigests.getSHA1().digest(sha1Input);
+                }
+                else
+                {
+                    mdResult = MessageDigests.getSHA256().digest(sha1Input);
+                }
 
                 // detect whether AES encryption is used. This assumes that the encryption algo is 
                 // stored in the PDCryptFilterDictionary
                 // However, crypt filters are used only when V is 4 or 5.
-                PDCryptFilterDictionary defaultCryptFilterDictionary = encryption.getDefaultCryptFilterDictionary();
                 if (defaultCryptFilterDictionary != null)
                 {
                     COSName cryptFilterMethod = defaultCryptFilterDictionary.getCryptFilterMethod();
@@ -257,8 +280,8 @@ public final class PublicKeySecurityHandler extends SecurityHandler
             }
 
             // we have the encryption key ...
-            encryptionKey = new byte[this.keyLength / 8];
-            System.arraycopy(mdResult, 0, encryptionKey, 0, this.keyLength / 8);
+            setEncryptionKey(new byte[getKeyLength() / 8]);
+            System.arraycopy(mdResult, 0, getEncryptionKey(), 0, getKeyLength() / 8);
         }
         catch (CMSException e)
         {
@@ -317,7 +340,7 @@ public final class PublicKeySecurityHandler extends SecurityHandler
             }
 
             dictionary.setFilter(FILTER);
-            dictionary.setLength(this.keyLength);
+            dictionary.setLength(getKeyLength());
             int version = computeVersionNumber();
             dictionary.setVersion(version);
 
@@ -366,22 +389,27 @@ public final class PublicKeySecurityHandler extends SecurityHandler
             }
 
             byte[] mdResult;
-            if (version == 4 || version == 5)
+            switch (version)
             {
-                dictionary.setSubFilter(SUBFILTER5);
-                mdResult = MessageDigests.getSHA256().digest(shaInput);
-                COSName aesVName = version == 5 ? COSName.AESV3 : COSName.AESV2;
-                prepareEncryptionDictAES(dictionary, aesVName, recipientsFields);
-            }
-            else
-            {
-                dictionary.setSubFilter(SUBFILTER4);
-                mdResult = MessageDigests.getSHA1().digest(shaInput);
-                dictionary.setRecipients(recipientsFields);
+                case 4:
+                    dictionary.setSubFilter(SUBFILTER5);
+                    mdResult = MessageDigests.getSHA1().digest(shaInput);
+                    prepareEncryptionDictAES(dictionary, COSName.AESV2, recipientsFields);
+                    break;
+                case 5:
+                    dictionary.setSubFilter(SUBFILTER5);
+                    mdResult = MessageDigests.getSHA256().digest(shaInput);
+                    prepareEncryptionDictAES(dictionary, COSName.AESV3, recipientsFields);
+                    break;
+                default:
+                    dictionary.setSubFilter(SUBFILTER4);
+                    mdResult = MessageDigests.getSHA1().digest(shaInput);
+                    dictionary.setRecipients(recipientsFields);
+                    break;
             }
 
-            this.encryptionKey = new byte[this.keyLength/8];
-            System.arraycopy(mdResult, 0, this.encryptionKey, 0, this.keyLength/8);
+            setEncryptionKey(new byte[getKeyLength() / 8]);
+            System.arraycopy(mdResult, 0, getEncryptionKey(), 0, getKeyLength() / 8);
 
             doc.setEncryptionDictionary(dictionary);
             doc.getDocument().setEncryptionDictionary(dictionary.getCOSObject());
@@ -392,35 +420,11 @@ public final class PublicKeySecurityHandler extends SecurityHandler
         }
     }
 
-    /**
-     * Computes the version number of the StandardSecurityHandler based on the encryption key
-     * length. See PDF Spec 1.6 p 93 and
-     * <a href="https://www.adobe.com/content/dam/acom/en/devnet/pdf/adobe_supplement_iso32000.pdf">PDF
-     * 1.7 Supplement ExtensionLevel: 3</a>
-     *
-     * @return The computed version number.
-     */
-    private int computeVersionNumber()
-    {
-        switch (keyLength)
-        {
-            case 40:
-                return 1;
-            case 128:
-                return 2; // prefer RC4 (AES 128 doesn't work yet)
-                //return 4; // prefer AES
-            case 256:
-                return 5;
-            default:
-                throw new IllegalArgumentException("key length must be 40, 128 or 256");
-        }
-    }
-
     private void prepareEncryptionDictAES(PDEncryption encryptionDictionary, COSName aesVName, byte[][] recipients)
     {
         PDCryptFilterDictionary cryptFilterDictionary = new PDCryptFilterDictionary();
         cryptFilterDictionary.setCryptFilterMethod(aesVName);
-        cryptFilterDictionary.setLength(keyLength);
+        cryptFilterDictionary.setLength(getKeyLength());
         COSArray array = new COSArray();
         for (byte[] recipient : recipients)
         {
@@ -437,8 +441,9 @@ public final class PublicKeySecurityHandler extends SecurityHandler
 
     private byte[][] computeRecipientsField(byte[] seed) throws GeneralSecurityException, IOException
     {
-        byte[][] recipientsField = new byte[policy.getNumberOfRecipients()][];
-        Iterator<PublicKeyRecipient> it = policy.getRecipientsIterator();
+        PublicKeyProtectionPolicy protectionPolicy = (PublicKeyProtectionPolicy) getProtectionPolicy();
+        byte[][] recipientsField = new byte[protectionPolicy.getNumberOfRecipients()][];
+        Iterator<PublicKeyRecipient> it = protectionPolicy.getRecipientsIterator();
         int i = 0;
         
         while(it.hasNext())
@@ -459,17 +464,13 @@ public final class PublicKeySecurityHandler extends SecurityHandler
             pkcs7input[21] = three;
             pkcs7input[22] = two;
             pkcs7input[23] = one;
-            
+
             ASN1Primitive obj = createDERForRecipient(pkcs7input, certificate);
-            
             ByteArrayOutputStream baos = new ByteArrayOutputStream();
-            
-            DEROutputStream k = new DEROutputStream(baos);
-            
-            k.writeObject(obj);
-            
+            obj.encodeTo(baos, ASN1Encoding.DER);
+
             recipientsField[i] = baos.toByteArray();
-            
+
             i++;
         }
         return recipientsField;
@@ -484,9 +485,10 @@ public final class PublicKeySecurityHandler extends SecurityHandler
         Cipher cipher;
         try
         {
-            apg = AlgorithmParameterGenerator.getInstance(algorithm, SecurityProvider.getProvider());
-            keygen = KeyGenerator.getInstance(algorithm, SecurityProvider.getProvider());
-            cipher = Cipher.getInstance(algorithm, SecurityProvider.getProvider());
+            Provider provider = SecurityProvider.getProvider();
+            apg = AlgorithmParameterGenerator.getInstance(algorithm, provider);
+            keygen = KeyGenerator.getInstance(algorithm, provider);
+            cipher = Cipher.getInstance(algorithm, provider);
         }
         catch (NoSuchAlgorithmException e)
         {
@@ -561,13 +563,4 @@ public final class PublicKeySecurityHandler extends SecurityHandler
         RecipientIdentifier recipientId = new RecipientIdentifier(serial);
         return new KeyTransRecipientInfo(recipientId, algorithmId, octets);
     }
-    
-    /**
-     * {@inheritDoc}
-     */
-    @Override
-    public boolean hasProtectionPolicy()
-    {
-        return policy != null;
-    }
 }
