@@ -28,6 +28,7 @@ import org.apache.pdfbox.cos.COSArray;
 import org.apache.pdfbox.cos.COSBase;
 import org.apache.pdfbox.cos.COSDictionary;
 import org.apache.pdfbox.cos.COSName;
+import org.apache.pdfbox.cos.COSNumber;
 import org.apache.pdfbox.cos.COSStream;
 import org.apache.pdfbox.pdmodel.PDResources;
 import org.apache.pdfbox.pdmodel.ResourceCache;
@@ -128,8 +129,8 @@ public class PDType3Font extends PDSimpleFont
     @Override
     public boolean hasGlyph(String name) throws IOException
     {
-        COSBase base = getCharProcs().getDictionaryObject(COSName.getPDFName(name));
-        return base instanceof COSStream;
+        return getCharProcs() == null ? false
+                : getCharProcs().getCOSStream(COSName.getPDFName(name)) != null;
     }
 
     @Override
@@ -244,19 +245,27 @@ public class PDType3Font extends PDSimpleFont
     {
         if (fontMatrix == null)
         {
-            COSBase base = dict.getDictionaryObject(COSName.FONT_MATRIX);
-            if (base instanceof COSArray)
-            {
-                fontMatrix = new Matrix((COSArray) base);
-            }
-            else
-            {
-                return super.getFontMatrix();
-            }
+            COSArray matrix = dict.getCOSArray(COSName.FONT_MATRIX);
+            fontMatrix = checkFontMatrixValues(matrix) ? Matrix.createMatrix(matrix)
+                    : super.getFontMatrix();
         }
         return fontMatrix;
     }
 
+    private boolean checkFontMatrixValues(COSArray matrix)
+    {
+        if (matrix == null || matrix.size() != 6)
+        {
+            return false;
+        }
+        for (COSBase element : matrix.toList())
+        {
+            if (!(element instanceof COSNumber))
+                return false;
+        }
+        return true;
+    }
+
     @Override
     public boolean isDamaged()
     {
@@ -317,32 +326,44 @@ public class PDType3Font extends PDSimpleFont
     private BoundingBox generateBoundingBox()
     {
         PDRectangle rect = getFontBBox();
+        if (rect == null)
+        {
+            LOG.warn("FontBBox missing, returning empty rectangle");
+            return new BoundingBox();
+        }
         if (rect.getLowerLeftX() == 0 && rect.getLowerLeftY() == 0
                 && rect.getUpperRightX() == 0 && rect.getUpperRightY() == 0)
         {
             // Plan B: get the max bounding box of the glyphs
             COSDictionary cp = getCharProcs();
-            for (COSName name : cp.keySet())
+            if (cp != null)
             {
-                COSBase base = cp.getDictionaryObject(name);
-                if (base instanceof COSStream)
+                for (COSName name : cp.keySet())
                 {
-                    PDType3CharProc charProc = new PDType3CharProc(this, (COSStream) base);
-                    try
+                    COSStream typ3CharProcStream = cp.getCOSStream(name);
+                    if (typ3CharProcStream != null)
                     {
-                        PDRectangle glyphBBox = charProc.getGlyphBBox();
-                        if (glyphBBox == null)
+                        PDType3CharProc charProc = new PDType3CharProc(this, typ3CharProcStream);
+                        try
                         {
-                            continue;
+                            PDRectangle glyphBBox = charProc.getGlyphBBox();
+                            if (glyphBBox == null)
+                            {
+                                continue;
+                            }
+                            rect.setLowerLeftX(
+                                    Math.min(rect.getLowerLeftX(), glyphBBox.getLowerLeftX()));
+                            rect.setLowerLeftY(
+                                    Math.min(rect.getLowerLeftY(), glyphBBox.getLowerLeftY()));
+                            rect.setUpperRightX(
+                                    Math.max(rect.getUpperRightX(), glyphBBox.getUpperRightX()));
+                            rect.setUpperRightY(
+                                    Math.max(rect.getUpperRightY(), glyphBBox.getUpperRightY()));
+                        }
+                        catch (IOException ex)
+                        {
+                            // ignore
                         }
-                        rect.setLowerLeftX(Math.min(rect.getLowerLeftX(), glyphBBox.getLowerLeftX()));
-                        rect.setLowerLeftY(Math.min(rect.getLowerLeftY(), glyphBBox.getLowerLeftY()));
-                        rect.setUpperRightX(Math.max(rect.getUpperRightX(), glyphBBox.getUpperRightX()));
-                        rect.setUpperRightY(Math.max(rect.getUpperRightY(), glyphBBox.getUpperRightY()));
-                    }
-                    catch (IOException ex)
-                    {
-                        // ignore
                     }
                 }
             }
@@ -373,16 +394,12 @@ public class PDType3Font extends PDSimpleFont
      */
     public PDType3CharProc getCharProc(int code)
     {
-        String name = getEncoding().getName(code);
-        if (getCharProcs() == null)
+        if (getEncoding() == null || getCharProcs() == null)
         {
             return null;
         }
+        String name = getEncoding().getName(code);
         COSStream stream = getCharProcs().getCOSStream(COSName.getPDFName(name));
-        if (stream != null)
-        {
-            return new PDType3CharProc(this, stream);
-        }
-        return null;
+        return stream != null ? new PDType3CharProc(this, stream) : null;
     }
 }
