@@ -195,23 +195,25 @@ abstract class TrueTypeEmbedder implements Subsetter
      */
     private PDFontDescriptor createFontDescriptor(TrueTypeFont ttf) throws IOException
     {
-        PDFontDescriptor fd = new PDFontDescriptor();
-        fd.setFontName(ttf.getName());
-
+        String ttfName = ttf.getName();
         OS2WindowsMetricsTable os2 = ttf.getOS2Windows();
         if (os2 == null)
         {
-            throw new IOException("os2 table is missing in font " + ttf.getName());
+            throw new IOException("os2 table is missing in font " + ttfName);
         }
         PostScriptTable post = ttf.getPostScript();
         if (post == null)
         {
-            throw new IOException("post table is missing in font " + ttf.getName());            
+            throw new IOException("post table is missing in font " + ttfName);            
         }
 
+        PDFontDescriptor fd = new PDFontDescriptor();
+        fd.setFontName(ttfName);
+
+        HorizontalHeaderTable hhea = ttf.getHorizontalHeader();
+
         // Flags
-        fd.setFixedPitch(post.getIsFixedPitch() > 0 ||
-                         ttf.getHorizontalHeader().getNumberOfHMetrics() == 1);
+        fd.setFixedPitch(post.getIsFixedPitch() > 0 || hhea.getNumberOfHMetrics() == 1);
 
         int fsSelection = os2.getFsSelection();
         fd.setItalic(((fsSelection & (ITALIC | OBLIQUE)) != 0));
@@ -251,9 +253,8 @@ abstract class TrueTypeEmbedder implements Subsetter
         fd.setFontBoundingBox(rect);
 
         // Ascent, Descent
-        HorizontalHeaderTable hHeader = ttf.getHorizontalHeader();
-        fd.setAscent(hHeader.getAscender() * scaling);
-        fd.setDescent(hHeader.getDescender() * scaling);
+        fd.setAscent(hhea.getAscender() * scaling);
+        fd.setDescent(hhea.getDescender() * scaling);
 
         // CapHeight, XHeight
         if (os2.getVersion() >= 1.2)
