@@ -77,6 +77,14 @@ public abstract class PDAbstractAppearanceHandler implements PDAppearanceHandler
         this.document = document;
     }
 
+    @Override
+    public void generateAppearanceStreams()
+    {
+        generateNormalAppearance();
+        generateRolloverAppearance();
+        generateDownAppearance();
+    }
+
     PDAnnotation getAnnotation()
     {
         return annotation;
