@@ -44,19 +44,15 @@ public class PDUnderlineAppearanceHandler extends PDAbstractAppearanceHandler
         super(annotation, document);
     }
 
-    @Override
-    public void generateAppearanceStreams()
-    {
-        generateNormalAppearance();
-        generateRolloverAppearance();
-        generateDownAppearance();
-    }
-
     @Override
     public void generateNormalAppearance()
     {
         PDAnnotationTextMarkup annotation = (PDAnnotationTextMarkup) getAnnotation();
         PDRectangle rect = annotation.getRectangle();
+        if (rect == null)
+        {
+            return;
+        }
         float[] pathsArray = annotation.getQuadPoints();
         if (pathsArray == null)
         {
