@@ -461,7 +461,7 @@ public class PDSeedValue implements COSObjectable
      */
     public PDSeedValueMDP getMDP()
     {
-        COSDictionary dict = (COSDictionary)dictionary.getDictionaryObject(COSName.MDP);
+        COSDictionary dict = dictionary.getCOSDictionary(COSName.MDP);
         PDSeedValueMDP mdp = null;
         if (dict != null)
         {
@@ -529,7 +529,7 @@ public class PDSeedValue implements COSObjectable
      */
     public PDSeedValueTimeStamp getTimeStamp()
     {
-        COSDictionary dict = (COSDictionary)dictionary.getDictionaryObject(COSName.TIME_STAMP);
+        COSDictionary dict = dictionary.getCOSDictionary(COSName.TIME_STAMP);
         PDSeedValueTimeStamp timestamp = null;
         if (dict != null)
         {
