@@ -23,6 +23,7 @@ import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.util.Arrays;
+import java.util.Collections;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Set;
@@ -46,6 +47,7 @@ import org.apache.pdfbox.pdmodel.graphics.image.PDImageXObject;
 import org.apache.pdfbox.pdmodel.graphics.pattern.PDAbstractPattern;
 import org.apache.pdfbox.pdmodel.graphics.pattern.PDTilingPattern;
 import org.apache.pdfbox.pdmodel.graphics.state.PDExtendedGraphicsState;
+import org.apache.pdfbox.pdmodel.graphics.state.PDGraphicsState;
 import org.apache.pdfbox.pdmodel.graphics.state.PDSoftMask;
 import org.apache.pdfbox.pdmodel.graphics.state.RenderingMode;
 import org.apache.pdfbox.tools.imageio.ImageIOUtil;
@@ -325,14 +327,15 @@ public final class ExtractImages
                                  int code,
                                  Vector displacement) throws IOException
         {
-            RenderingMode renderingMode = getGraphicsState().getTextState().getRenderingMode();
+            PDGraphicsState graphicsState = getGraphicsState();
+            RenderingMode renderingMode = graphicsState.getTextState().getRenderingMode();
             if (renderingMode.isFill())
             {
-                processColor(getGraphicsState().getNonStrokingColor());
+                processColor(graphicsState.getNonStrokingColor());
             }
             if (renderingMode.isStroke())
             {
-                processColor(getGraphicsState().getStrokingColor());
+                processColor(graphicsState.getStrokingColor());
             }
         }
 
@@ -464,7 +467,7 @@ public final class ExtractImages
                     {
                         // RGB or Gray colorspace: get and write the unmodified JPEG2000 stream
                         InputStream data = pdImage.createInputStream(
-                                Arrays.asList(COSName.JPX_DECODE.getName()));
+                                Collections.singletonList(COSName.JPX_DECODE.getName()));
                         IOUtils.copy(data, out);
                         IOUtils.closeQuietly(data);
                     }
