@@ -24,11 +24,12 @@ package org.apache.xmpbox.xml;
 import java.io.ByteArrayInputStream;
 import java.io.IOException;
 import java.io.InputStream;
+import java.util.ArrayDeque;
 import java.util.ArrayList;
+import java.util.Deque;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
-import java.util.Stack;
 import java.util.StringTokenizer;
 
 import javax.xml.XMLConstants;
@@ -91,7 +92,7 @@ public class DomXmpParser
         }
         catch (ParserConfigurationException e)
         {
-            throw new XmpParsingException(ErrorType.Configuration, "Failed to initilalize", e);
+            throw new XmpParsingException(ErrorType.Configuration, "Failed to initialize", e);
         }
     }
 
@@ -372,6 +373,11 @@ public class DomXmpParser
         if (DomHelper.isParseTypeResource(property))
         {
             AbstractStructuredType ast = parseLiDescription(xmp, DomHelper.getQName(property), property);
+            if (ast == null)
+            {
+                throw new XmpParsingException(ErrorType.Format, "property should contain child elements : "
+                        + property);
+            }
             ast.setPrefix(prefix);
             container.addProperty(ast);
         }
@@ -384,6 +390,11 @@ public class DomXmpParser
                         + property);
             }
             AbstractStructuredType ast = parseLiDescription(xmp, DomHelper.getQName(property), inner);
+            if (ast == null)
+            {
+                throw new XmpParsingException(ErrorType.Format, "inner element should contain child elements : "
+                        + inner);
+            }
             ast.setPrefix(prefix);
             container.addProperty(ast);
         }
@@ -408,6 +419,11 @@ public class DomXmpParser
             {
                 nsFinder.push(inner);
                 AbstractStructuredType ast = parseLiDescription(xmp, DomHelper.getQName(property), inner);
+                if (ast == null)
+                {
+                    throw new XmpParsingException(ErrorType.Format, "inner element should contain child elements : "
+                            + inner);
+                }
                 ast.setPrefix(prefix);
                 container.addProperty(ast);
             }
@@ -901,8 +917,7 @@ public class DomXmpParser
 
     protected static class NamespaceFinder
     {
-
-        private final Stack<Map<String, String>> stack = new Stack<Map<String, String>>();
+        private final Deque<Map<String, String>> stack = new ArrayDeque<Map<String, String>>();
 
         protected void push(Element description)
         {
@@ -927,9 +942,8 @@ public class DomXmpParser
 
         protected boolean containsNamespace(String namespace)
         {
-            for (int i = stack.size() - 1; i >= 0; i--)
+            for (Map<String,String> map : stack)
             {
-                Map<String, String> map = stack.get(i);
                 if (map.containsValue(namespace))
                 {
                     return true;
